@@ -89,9 +89,9 @@ our @ISA = qw(HTML::Parser);
 use HTML::Entities ();
 
 use strict;
-use vars qw($DEBUG);
+our $DEBUG;
 #$DEBUG = 1;
-our $VERSION = '3.75';
+our $VERSION = '3.76';
 
 =item $hp = HTML::HeadParser->new
 
